//[mahjong-utils](../../index.md)/[mahjongutils](index.md)

# Package-level declarations

## Types

| Name | Summary |
|---|---|
| [CalcContext](-calc-context/index.md) | [common]<br>class [CalcContext](-calc-context/index.md) |
| [ErrorInfo](-error-info/index.md) | [common]<br>interface [ErrorInfo](-error-info/index.md) |
| [ValidationException](-validation-exception/index.md) | [common]<br>open class [ValidationException](-validation-exception/index.md)(val errors: [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[ErrorInfo](-error-info/index.md)&gt;) : [RuntimeException](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-runtime-exception/index.html) |
